Crate blitz_shell

Crate blitz_shell 

Event loop, windowing and system integration.

Feature flags

  • default: Enables the features listed below.
  • accessibility: Enables accesskit accessibility support.
  • hot-reload: Enables hot-reloading of Dioxus RSX.
  • tracing: Enables tracing support.

Re-exports

pub use crate::frame_stats::FrameStatsSnapshot;
pub use crate::frame_stats::FrameTimings;
pub use crate::frame_stats::TimingStats;
pub use crate::frame_stats::clear_frame_stats;
pub use crate::frame_stats::latest_frame_stats;

Modules

frame_stats
Process-global publication of real per-frame timings.

Structs

BlitzApplication
BlitzShellProvider
BlitzShellProxy
Config
DataUriNetProviderdata-uri
DeepProfilingSessiondebug-control
Holds a deep-profiling capture open across the shell and script collectors.
EventLoop
Provides a way to retrieve events from the system and from the windows that were registered to the events loop.
EventLoopProxy
Control the ActiveEventLoop, possibly from a different thread, without referencing it directly.
View
WindowConfig

Enums

BlitzShellEvent
ControlFlow
Set through ActiveEventLoop::set_control_flow().

Traits

Window
Represents a window.

Functions

begin_deep_profilingdebug-control
Ask for samples, for as long as the returned guard is held.
create_default_event_loop
Build an event loop for the application
set_deep_profiling_permitteddebug-control
Permit or forbid deep profiling for this process.