pub struct EventLoopProxy { /* private fields */ }Expand description
Control the ActiveEventLoop, possibly from a different thread, without referencing it
directly.
Implementations
Sourceimpl EventLoopProxy
impl EventLoopProxy
Sourcepub fn wake_up(&self)
pub fn wake_up(&self)
Wake up the ActiveEventLoop, resulting in ApplicationHandler::proxy_wake_up() being
called.
Calls to this method are coalesced into a single call to proxy_wake_up, see the
documentation on that for details.
If the event loop is no longer running, this is a no-op.
Platform-specific
- Windows: The wake-up may be ignored under high contention, see #3687.
pub fn new(proxy: Arc<dyn EventLoopProxyProvider>) -> EventLoopProxy