Re-exports
pub use crate::frame_stats::FrameStatsSnapshot;pub use crate::frame_stats::FrameTimings;pub use crate::frame_stats::TimingStats;pub use crate::frame_stats::clear_frame_stats;pub use crate::frame_stats::latest_frame_stats;
Modules
- frame_
stats - Process-global publication of real per-frame timings.
Structs
- Blitz
Application - Blitz
Shell Provider - Blitz
Shell Proxy - Config
- Data
UriNet Provider data-uri - Deep
Profiling Session debug-control - Holds a deep-profiling capture open across the shell and script collectors.
- Event
Loop - Provides a way to retrieve events from the system and from the windows that were registered to the events loop.
- Event
Loop Proxy - Control the
ActiveEventLoop, possibly from a different thread, without referencing it directly. - View
- Window
Config
Enums
Traits
- Window
- Represents a window.
Functions
- begin_
deep_ profiling debug-control - Ask for samples, for as long as the returned guard is held.
- create_
default_ event_ loop - Build an event loop for the application
- set_
deep_ profiling_ permitted debug-control - Permit or forbid deep profiling for this process.