Structs
- Blitz
Application - Blitz
Shell Provider - Blitz
Shell Proxy - Config
- Data
UriNet Provider data-uri - Event
Loop - Provides a way to retrieve events from the system and from the windows that were registered to the events loop.
- Event
Loop Proxy - Control the
ActiveEventLoop, possibly from a different thread, without referencing it directly. - View
- Window
Config
Enums
Traits
- Window
- Represents a window.
Functions
- create_
default_ event_ loop - Build an event loop for the application